@@ -1062,10 +1062,6 @@ gsd_a11y_keyboard_manager_set_property (GObject        *object,
                                         const GValue   *value,
                                         GParamSpec     *pspec)
 {
-        GsdA11yKeyboardManager *self;
-
-        self = GSD_A11Y_KEYBOARD_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1079,10 +1075,6 @@ gsd_a11y_keyboard_manager_get_property (GObject        *object,
                                         GValue         *value,
                                         GParamSpec     *pspec)
 {
-        GsdA11yKeyboardManager *self;
-
-        self = GSD_A11Y_KEYBOARD_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1096,9 +1088,6 @@ gsd_a11y_keyboard_manager_constructor (GType                  type,
                                        GObjectConstructParam *construct_properties)
 {
         GsdA11yKeyboardManager      *a11y_keyboard_manager;
-        GsdA11yKeyboardManagerClass *klass;
-
-        klass = GSD_A11Y_KEYBOARD_MANAGER_CLASS (g_type_class_peek (GSD_TYPE_A11Y_KEYBOARD_MANAGER));
 
         a11y_keyboard_manager = GSD_A11Y_KEYBOARD_MANAGER (G_OBJECT_CLASS (gsd_a11y_keyboard_manager_parent_class)->constructor (type,
                                                                                                       n_construct_properties,
@@ -1110,10 +1099,6 @@ gsd_a11y_keyboard_manager_constructor (GType                  type,
 static void
 gsd_a11y_keyboard_manager_dispose (GObject *object)
 {
-        GsdA11yKeyboardManager *a11y_keyboard_manager;
-
-        a11y_keyboard_manager = GSD_A11Y_KEYBOARD_MANAGER (object);
-
         G_OBJECT_CLASS (gsd_a11y_keyboard_manager_parent_class)->dispose (object);
 }
 
@@ -1173,6 +1158,7 @@ gsd_a11y_keyboard_manager_ensure_status_icon (GsdA11yKeyboardManager *manager)
         if (!manager->priv->status_icon) {
 
                 manager->priv->status_icon = gtk_status_icon_new_from_icon_name ("preferences-desktop-accessibility");
+                gtk_status_icon_set_name (manager->priv->status_icon, "a11y-keyboard");
                 g_signal_connect (manager->priv->status_icon,
                                   "activate",
                                   G_CALLBACK (on_status_icon_activate),
