@@ -507,7 +507,7 @@ do_media_action (GsdMediaKeysManager *manager)
 static void
 do_logout_action (GsdMediaKeysManager *manager)
 {
-        execute (manager, "gnome-session-save --logout-dialog", FALSE, FALSE);
+        execute (manager, "gnome-session-quit --logout", FALSE, FALSE);
 }
 
 static void
@@ -1086,96 +1086,61 @@ do_on_screen_keyboard_action (GsdMediaKeysManager *manager)
         do_toggle_accessibility_key ("screen-keyboard-enabled");
 }
 
-/* The following two functions taken from gsd-a11y-preferences-dialog.c
- *
- * Copyright (C)  2008 William Jon McCann <jmccann@redhat.com>
- *
- * Licensed under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- */
-/* X servers sometimes lie about the screen's physical dimensions, so we cannot
- * compute an accurate DPI value.  When this happens, the user gets fonts that
- * are too huge or too tiny.  So, we see what the server returns:  if it reports
- * something outside of the range [DPI_LOW_REASONABLE_VALUE,
- * DPI_HIGH_REASONABLE_VALUE], then we assume that it is lying and we use
- * DPI_FALLBACK instead.
- *
- * See get_dpi_from_x_server() below, and also
- * https://bugzilla.novell.com/show_bug.cgi?id=217790
- */
-#define DPI_LOW_REASONABLE_VALUE 50
-#define DPI_HIGH_REASONABLE_VALUE 500
-#define DPI_DEFAULT        96
-
-static gdouble
-dpi_from_pixels_and_mm (gint pixels,
-			gint mm)
-{
-	if (mm >= 1)
-		return pixels / (mm / 25.4);
-	else
-		return 0;
-}
-
-static gdouble
-get_dpi_from_x_server (GdkScreen *screen)
-{
-	gdouble dpi;
-
-	if (screen) {
-		gdouble width_dpi, height_dpi;
-
-		width_dpi = dpi_from_pixels_and_mm (gdk_screen_get_width (screen),
-						    gdk_screen_get_width_mm (screen));
-		height_dpi = dpi_from_pixels_and_mm (gdk_screen_get_height (screen),
-						     gdk_screen_get_height_mm (screen));
-
-		if (width_dpi < DPI_LOW_REASONABLE_VALUE
-		    || width_dpi > DPI_HIGH_REASONABLE_VALUE
-		    || height_dpi < DPI_LOW_REASONABLE_VALUE
-		    || height_dpi > DPI_HIGH_REASONABLE_VALUE) {
-			dpi = DPI_DEFAULT;
-		} else {
-			dpi = (width_dpi + height_dpi) / 2.0;
-		}
-	} else {
-		dpi = DPI_DEFAULT;
-	}
-
-	return dpi;
-}
-
 static void
 do_text_size_action (GsdMediaKeysManager *manager,
 		     MediaKeyType         type)
 {
-	GSettings *font_settings;
-	gdouble x_dpi, u_dpi, factor;
-
-	font_settings = g_settings_new (SETTINGS_XSETTINGS_DIR);
-
-	/* Figure out the current DPI scaling factor */
-	u_dpi = g_settings_get_double (font_settings, "dpi");
-	x_dpi = get_dpi_from_x_server (manager->priv->current_screen);
-	if (u_dpi == 0.0)
-		factor = 1.0;
-	else
-		factor = u_dpi / x_dpi;
-
-	/* Increasing text size means increasing the DPI */
-	factor += (type == INCREASE_TEXT_KEY ? 0.25 : -0.25);
+	gdouble factor, best, distance;
+	guint i;
 
 	/* Same values used in the Seeing tab of the Universal Access panel */
-	if (fabs (factor - 1.0)  < 1e6 ||
-	    factor < 1.0) {
-		g_settings_reset (font_settings, "dpi");
-	} else if (factor > 1.0 && factor <= 1.25) {
-		g_settings_set_double (font_settings, "dpi", 1.25);
-	} else {
-		g_settings_set_double (font_settings, "dpi", 1.5);
+	static gdouble factors[] = {
+		0.75,
+		1.0,
+		1.25,
+		1.5
+	};
+
+	/* Figure out the current DPI scaling factor */
+	factor = g_settings_get_double (manager->priv->interface_settings, "text-scaling-factor");
+	factor += (type == INCREASE_TEXT_KEY ? 0.25 : -0.25);
+
+	/* Try to find a matching value */
+	distance = 1e6;
+	best = 1.0;
+	for (i = 0; i < G_N_ELEMENTS(factors); i++) {
+		gdouble d;
+		d = fabs (factor - factors[i]);
+		if (d < distance) {
+			best = factors[i];
+			distance = d;
+		}
 	}
-	g_object_unref (font_settings);
+
+	if (best == 1.0)
+		g_settings_reset (manager->priv->interface_settings, "text-scaling-factor");
+	else
+		g_settings_set_double (manager->priv->interface_settings, "text-scaling-factor", best);
+}
+
+static void
+do_magnifier_zoom_action (GsdMediaKeysManager *manager,
+			  MediaKeyType         type)
+{
+	GSettings *settings;
+	gdouble offset, value;
+
+	if (type == MAGNIFIER_ZOOM_IN_KEY)
+		offset = 1.0;
+	else
+		offset = -1.0;
+
+	settings = g_settings_new ("org.gnome.desktop.a11y.magnifier");
+	value = g_settings_get_double (settings, "mag-factor");
+	value += offset;
+	value = roundl (value);
+	g_settings_set_double (settings, "mag-factor", value);
+	g_object_unref (settings);
 }
 
 static void
@@ -1312,6 +1277,10 @@ do_action (GsdMediaKeysManager *manager,
 	case DECREASE_TEXT_KEY:
 		do_text_size_action (manager, type);
 		break;
+	case MAGNIFIER_ZOOM_IN_KEY:
+	case MAGNIFIER_ZOOM_OUT_KEY:
+		do_magnifier_zoom_action (manager, type);
+		break;
 	case TOGGLE_CONTRAST_KEY:
 		do_toggle_contrast_action (manager);
 		break;
@@ -1585,10 +1554,6 @@ gsd_media_keys_manager_set_property (GObject        *object,
                                const GValue   *value,
                                GParamSpec     *pspec)
 {
-        GsdMediaKeysManager *self;
-
-        self = GSD_MEDIA_KEYS_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1602,10 +1567,6 @@ gsd_media_keys_manager_get_property (GObject        *object,
                                GValue         *value,
                                GParamSpec     *pspec)
 {
-        GsdMediaKeysManager *self;
-
-        self = GSD_MEDIA_KEYS_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1619,9 +1580,6 @@ gsd_media_keys_manager_constructor (GType                  type,
                               GObjectConstructParam *construct_properties)
 {
         GsdMediaKeysManager      *media_keys_manager;
-        GsdMediaKeysManagerClass *klass;
-
-        klass = GSD_MEDIA_KEYS_MANAGER_CLASS (g_type_class_peek (GSD_TYPE_MEDIA_KEYS_MANAGER));
 
         media_keys_manager = GSD_MEDIA_KEYS_MANAGER (G_OBJECT_CLASS (gsd_media_keys_manager_parent_class)->constructor (type,
                                                                                                       n_construct_properties,
@@ -1684,7 +1642,6 @@ on_bus_gotten (GObject             *source_object,
                GsdMediaKeysManager *manager)
 {
         GDBusConnection *connection;
-        guint registration_id;
         GError *error = NULL;
 
         connection = g_bus_get_finish (res, &error);
@@ -1695,13 +1652,13 @@ on_bus_gotten (GObject             *source_object,
         }
         manager->priv->connection = connection;
 
-        registration_id = g_dbus_connection_register_object (connection,
-                                                             GSD_MEDIA_KEYS_DBUS_PATH,
-                                                             manager->priv->introspection_data->interfaces[0],
-                                                             &interface_vtable,
-                                                             manager,
-                                                             NULL,
-                                                             NULL);
+        g_dbus_connection_register_object (connection,
+                                           GSD_MEDIA_KEYS_DBUS_PATH,
+                                           manager->priv->introspection_data->interfaces[0],
+                                           &interface_vtable,
+                                           manager,
+                                           NULL,
+                                           NULL);
 
         g_dbus_proxy_new (manager->priv->connection,
                           G_DBUS_PROXY_FLAGS_NONE,
